#include "InvVolSort.h"

/*!
* @class InvVolSort
* @brief sorts layers according to their inverse volatility 
*	
*/

/*!
* @brief default constructor
*	
*/
InvVolSort::InvVolSort(void)
{
}

/*!
* @brief returns sorting name
* @return QString: sorting name 
*	
*/
QString InvVolSort::getName()
{
	return "Inverse Volatility Sorting, Evenly Weighted";
}

/*!
* @brief operator for sort()
* @param Layer aL: layer a for comparing
* @param Layer bL: layer b for comparing
* @return bool: true if a>b
*	
*/
bool invVolFunc (Layer aL,Layer bL) { return (aL.volatility>bL.volatility); }

/*!
* @brief sorts layers according to inverse volatility
* @param Layer* layers: layers to be sorted
* @param int numLayers: number of layers
* @return Layer*: sorted layers
*	
*/
Layer* InvVolSort::sortLayers(Layer* layers, int numLayers) {
	vector <Layer> temp;


	for(int i=0; i<numLayers; i++){
		temp.push_back(layers[i]);
	}

	sort (temp.begin(), temp.end(), invVolFunc);  

	for(int i=0; i<numLayers; i++){
		layers[i] = temp.at(i);
	}

	return orderToOutside(layers, numLayers);
}

/*!
* @brief default destructor
*	
*/
InvVolSort::~InvVolSort(void)
{
}
