#include <stdio.h>
#include <algorithm>
#include <cmath>
#include "Layer.h"
using namespace std;

/*!
 * @class Layer
 * @brief holds a layers information and calculates its onset, end and volatility
 *	
 */

/*!
 * @brief default constuctor
 *	
 */
Layer::Layer()
{

}

/*!
 * @brief constructor, takes the layer's name and it's values
 * @param QString name: layers name (e.g. artist)
 * @param int* size: array with values for each timeslice (e.g. week)
 * @param int sizeLength: length of size array
 *	
 */
Layer::Layer(QString name, int* size, int sizeLength)
{
    // check for reasonable data
    for (int i = 0; i < sizeLength; i++) {
      if (size[i] < 0) {
         printf("\n data should not be < 0 !!");
      }
    }

    this->name  = name;
    this->size  = size;
    yBottom     = new float[sizeLength];
    yTop        = new float[sizeLength];
    sum         = 0;
    volatility  = 0;
    onset       = -1;
	end			= -1;

    //printf(name.data()->to);
    for (int i = 0; i < sizeLength; i++) {

      // sum is the summation of all points
      sum += size[i];

      // onset is the first non-zero point
      // end is the last non-zero point
      if (size[i] > 0) {
        if (onset == -1) {
          onset = i;
        } else {
          end = i;
        }
      }

      // volatility is the maximum change between any two consecutive points
      if (i > 0) {
		  //volatility = std::mamax( volatility, abs(size[i] - size[i-1]) );
		  volatility = volatility > abs(size[i] - size[i-1]) ? volatility : abs(size[i] - size[i-1]); // max(i,j)
      }
	}
	if(end == -1) end = onset+1;

}
