#include "LayerSorter.h"

/*!
 * @class LayerSorter
 * @brief base class for layer sorting
 *	
 */

/*!
 * @brief default constructor
 *	
 */
LayerSorter::LayerSorter()
{
}

/*!
 * @brief reorders sorted layers so that they are weighted according to their sum
 * @param Layer* layers: sorted layers
 * @param int numLayers: number of layers
 * @return Layer*: weighted layers
 *	
 */
Layer* LayerSorter::orderToOutside(Layer* layers, int numLayers)
{
	int j             = 0;
	int n             = numLayers;
	Layer *newLayers;
	newLayers = new Layer[n];
	int topCount      = 0;
	float topSum      = 0;
	int *topList;
	topList = new int[n];
	int botCount      = 0;
	float botSum      = 0;
	int *botList;
	botList = new int[n];

	// partition to top or bottom containers
	for (int i=0; i<n; i++) {
		if (topSum < botSum) {
			topList[topCount++] = i;
			topSum += layers[i].sum;
		} else {
			botList[botCount++] = i;
			botSum += layers[i].sum;
		}
	}

	// reassemble into single array
	for (int i = botCount - 1; i >= 0; i--) {
		newLayers[j++] = layers[botList[i]];
	}
	for (int i = 0; i < topCount; i++) {
		newLayers[j++] = layers[topList[i]];
	}
	return newLayers;
}

/*!
 * @brief default destructor
 *	
 */
LayerSorter::~LayerSorter()
{
}
