#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QFileDialog>
#include <QGraphicsItem>
#include <QDate>
#include "GraphicsScene.h"
#include "GraphicsView.h"
#include "StreamGraph.h"
#include "TFpopup.h"
#include "ResizeDialog.h"

namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow {
    Q_OBJECT
public:
    MainWindow(QWidget *parent = 0);
    ~MainWindow();
	StreamGraph *graph;
	GraphicsView *view;
	GraphicsScene *scene;
	TFpopup *tfpop;
	ResizeDialog *resizeD;

protected:
    void changeEvent(QEvent *e);

private:
    Ui::MainWindow *ui;
	int seed;
	float* colors;
	bool showGrid;
	int width, height;
	QPoint top, bottom;
	int screenCount;
	void drawGrid();
	void drawScene();

public slots:
		void fileOpen();
        void close();
        void refresh();
		void sortOrder(int i);
		void layoutSelect(int i);
		void scaleX(int i);
		void scaleY(int i);
		void showLabel(int pos, Layer lay);
		void showTF();
		void updateColorPalette(float* colors);
		void setColorCriterion(int i);
		void toggleAA(bool on);
		void toggleGrid(bool on);
		void toggle2D(bool on);
		void takeScreen();
		void showResizeDialog();
		void resizeScene(int w, int h);
		void moveYAxis(int i);
};

#endif // MAINWINDOW_H
