#include "MinWiggleLayout.h"

/*!
*	@class MinWiggleLayout
*	@brief calculates the baseline for the MinWiggleLayout layout
*/

/*!
* @brief default constructor
*	
*/
MinWiggleLayout::MinWiggleLayout()
{
}

/*!
* @brief returns layout name
* @return QString name
*	
*/
QString MinWiggleLayout::getName() {
	return "Minimized Wiggle Layout";
}

/*!
* @brief calculates the baseline for MinWiggleLayout layout
* @param Layer* layers contains all layers
* @param int numLayers number of layers
* @param int numElements length of layers
*	
*/
void MinWiggleLayout::layout(Layer* layers, int numLayers, int numElements) {
	float *baseline;
	baseline = new float[numElements];

	// Set shape of baseline values.
	for (int i = 0; i < numElements; i++) {
		for (int j = 0; j < numLayers; j++) {
			baseline[i] += (numLayers - j - 0.5) * layers[j].size[i];
		}
		baseline[i] /= numLayers;
	}

	// Put layers on top of the baseline.
	stackOnBaseline(layers, baseline, numLayers, numElements);
}

/*!
* @brief default destructor
*	
*/
MinWiggleLayout::~MinWiggleLayout()
{
}
