#include "OnsetSort.h"

/*!
 * @class OnsetSort
 * @brief sorts layers according to their onset value 
 *	
 */

/*!
 * @brief default constructor
 *	
 */
OnsetSort::OnsetSort(void)
{
}

/*!
 * @brief returns sorting name
 * @return QString: sorting name 
 *	
 */
QString OnsetSort::getName()
{
	return "Late Onset Sorting, Evenly Weighted";
}

/*!
 * @brief operator for sort()
 * @param Layer aL: layer a for comparing
 * @param Layer bL: layer b for comparing
 * @return bool: true if a<b
 *	
 */
bool onsetOp (Layer aL,Layer bL) { return (aL.onset<bL.onset); }

/*!
 * @brief sorts layers according to onset
 * @param Layer* layers: layers to be sorted
 * @param int numLayers: number of layers
 * @return Layer*: sorted layers
 *	
 */
Layer* OnsetSort::sortLayers(Layer* layers, int numLayers) {
	vector <Layer> temp;


	for(int i=0; i<numLayers; i++){
		temp.push_back(layers[i]);
	}

	sort (temp.begin(), temp.end(), onsetOp);  

	for(int i=0; i<numLayers; i++){
		layers[i] = temp.at(i);
	}

	return orderToOutside(layers, numLayers);
}

/*!
 * @brief default destructor
 *	
 */
OnsetSort::~OnsetSort(void)
{
}
