
#ifndef STREAMGRAPH_H
#define STREAMGRAPH_H

#include <QBrush>
#include <QPen>
#include <QPixmap>
#include <QWidget>

#include <iostream>
#include <fstream>
#include <string>
#include <vector>

#include "DataGenerator.h"
#include "Layer.h"

#include "VolSorter.h"
#include "InvVolSort.h"
#include "NoSort.h"
#include "BasicOnsetSort.h"
#include "OnsetSort.h"

#include "StackLayout.h"
#include "ThemeRiverLayout.h"
#include "StreamLayout.h"
#include "MinWiggleLayout.h"
using namespace std;

class StreamGraph : public QWidget
{
    Q_OBJECT

public:

    StreamGraph(int dimX, int dimY, QWidget *parent = 0 );
	void generateGraph(int seed);
	void updateGraph();
	void setLayout(int ls);
	void setSort(int order);
	Layer* getLayers();
	void setXscale( int sc);
	void setYscale( int sc);
	void loadNewGraph(QString fileName);
	void updateColorPalette(float* colors);

    int j, dimX, dimY;
    DataGenerator data;
    Layer *layers;
    int arrayLength;
	int numberOfLayers;
	int debugLength;
	int sortOrder;
	int layoutSelect;

	BasicOnsetSort basicOnset;
	OnsetSort onsetSort;
	VolSorter volSort;
	InvVolSort invVolSorting;
	NoSort noSorting;

	StreamLayout strLayout;
	MinWiggleLayout minWigLayout;
	StackLayout layout;
	ThemeRiverLayout thrvLayout;
	int criterion;
	float startX;
	int scale;
	int yMax;
	int yMin;
	bool twoD;

public slots:

private:
	int returnIndex(vector<string>vec, string art);
	void csvline_populate(vector<string> &record, const string& line, char delimiter);
	float* getMinMaxVolatility();
	float* getMinMaxOnset();
	float* getMinMaxEnd();
	float* getMinMaxSum();
	float* getMinMax(int crit);

    int width, height, xpos, ypos;
    float middleY;
	int yScale;
	float* colors;
};


#endif
