#include "StreamLayout.h"
/*!
*	@class StreamLayout
@brief calculates the baseline for the streamgraph layout
*/

/*!
 * @brief default constructor
 *	
 */
StreamLayout::StreamLayout()
{
}

/*!
* @brief returns layout name
* @return QString name
*	
*/
QString StreamLayout::getName() {
	return "Original Streamgraph Layout";
}

/*!
* @brief calculates the baseline for streamgraph layout
* @param Layer* layers contains all layers
* @param int numLayers number of layers
* @param int numElements length of layers
*	
*/
void StreamLayout::layout(Layer* layers, int numLayers, int numElements) {
	float *baseline;
	baseline = new float[numElements];
	float *center;
	center = new float[numElements];
	float totalSize;
	float moveUp;
	float increase;
	float belowSize;

	// Set shape of baseline values.
	for (int i = 0; i < numElements; i++) {
		// the 'center' is a rolling point. It is initialized as the previous
		// iteration's center value
		center[i] = i == 0 ? 0 : center[i-1];

		// find the total size of all layers at this point
		totalSize = 0;
		for (int j = 0; j < numLayers; j++) {
			totalSize += layers[j].size[i];
		}

		// account for the change of every layer to offset the center point
		for (int j = 0; j < numLayers; j++) {
			if (i == 0) {
				increase = layers[j].size[i];
				moveUp = 0.5f;
			} else {
				belowSize = 0.5f * layers[j].size[i];
				for (int k = j + 1; k < numLayers; k++) {
					belowSize += layers[k].size[i];
				}
				increase = layers[j].size[i] - layers[j].size[i - 1];
				moveUp = totalSize == 0 ? 0 : (belowSize / totalSize);
			}
			center[i] += (moveUp - 0.5) * increase;
		}

		// set baseline to the bottom edge according to the center line
		baseline[i] = center[i] + 0.5f * totalSize;
	}

	// Put layers on top of the baseline.
	stackOnBaseline(layers, baseline, numLayers, numElements);
}

/*!
* @brief default destructor
*	
*/
StreamLayout::~StreamLayout()
{
}
