#include "TFpopup.h"
/*!
	@class TFpopup
 *	@brief class of color palette popup window

	Implements popup's UI functionality.
 */

/*!
 * \brief
 * Initialize transfer function popup.
 *
 * Creates new TFWidget and connects all SIGNALs to appropriate SLOTS.
 * 
 */
TFpopup::TFpopup(QWidget *parent): QDialog(parent)
{
	setupUi(this);
	transFunc = new TFWidget;
	transFunc->setFixedSize(512,256);
	tflayout->addWidget(transFunc);

	add_mode->setChecked(true);
	connect(add_mode, SIGNAL(clicked()), this, SLOT(addMode()));
	connect(delete_mode, SIGNAL(clicked()), this, SLOT(delMode()));
	connect(closeButton, SIGNAL(clicked()), this, SLOT(closePopup()));
	connect(resetButton, SIGNAL(clicked()), this, SLOT(resetTF()));
	connect(transFunc, SIGNAL(functionChanged(float*)), this, SIGNAL(sendFunction(float*)));
	connect(save_button, SIGNAL(clicked()), this, SLOT(saveTF()));
	connect(load_button, SIGNAL(clicked()), this, SLOT(loadTF()));
	connect(onset_radio, SIGNAL(clicked()), this, SLOT(setOnset()));
	connect(vol_radio, SIGNAL(clicked()), this, SLOT(setVol()));
	connect(end_radio, SIGNAL(clicked()), this, SLOT(setEnd()));
	connect(sum_radio, SIGNAL(clicked()), this, SLOT(setSum()));
	connect(twoD_checkbox, SIGNAL(toggled(bool)), this, SIGNAL(toggled2D(bool)));

}

/*!
 * \brief
 * SLOT that gets called when add-mode radio button is activated. Sets TFWidget to add-vertex-mode.
 * 
 */
void TFpopup::addMode()
{
	transFunc->addMode();
}

/*!
* \brief
* SLOT that gets called when delete-mode radio button is activated. Sets TFWidget to delete-vertex-mode.
* 
*/
void TFpopup::delMode()
{
	transFunc->delMode();
}

/*!
 * \brief
 * SLOT that gets called when close button is clicked. Hides this popup.
 * 
 */
void TFpopup::closePopup()
{
	this->hide();
}

/*!
 * \brief
 * SLOT that is called when reset button is clicked. Resets TWWidget.
 * 
 */
void TFpopup::resetTF()
{
	transFunc->resetTF();
}

/*!
 * \brief
 * SLOT that is called when save button is clicked. Saves transfer function.
 *
 * Calls save function in TFWidget after file was chosen.
 * 
 */
void TFpopup::saveTF()
{
	QString fileName = QFileDialog::getSaveFileName(this,
		tr("Save  Transfer Function"), "",
		tr("TF File (*.tf);;All Files (*)"));

	if (fileName.isEmpty())
		return;
	else {
		QFile file(fileName);
		if (!file.open(QIODevice::WriteOnly)) {
			QMessageBox::information(this, tr("Unable to open file"),
				file.errorString());
			return;
		}
		transFunc->save(&file);
	}
}

/*!
* \brief
* SLOT that is called when load button is clicked. Loads transfer function.
*
* Calls load function in TFWidget after file was chosen.
* 
*/
void TFpopup::loadTF()
{
	QString fileName = QFileDialog::getOpenFileName(this,
		tr("Open Transfer Function"), "",
		tr("TF File (*.tf);;All Files (*)"));

	if (fileName.isEmpty())
		return;
	else
	{

		QFile file(fileName);

		if (!file.open(QIODevice::ReadOnly))
		{
			QMessageBox::information(this, tr("Unable to open file"),
				file.errorString());
			return;
		}
		transFunc->load(&file);
	}
}

/*!
 *	@brief SLOT that emits the changeColorCriterion() SIGNAL when triggered.
 */
void TFpopup::setOnset()
{
	emit changeColorCriterion(1);
}

/*!
*	@brief SLOT that emits the changeColorCriterion() SIGNAL when triggered.
*/
void TFpopup::setEnd()
{
	emit changeColorCriterion(3);
}

/*!
*	@brief SLOT that emits the changeColorCriterion() SIGNAL when triggered.
*/
void TFpopup::setVol()
{
	emit changeColorCriterion(0);
}

/*!
*	@brief SLOT that emits the changeColorCriterion() SIGNAL when triggered.
*/
void TFpopup::setSum()
{
	emit changeColorCriterion(2);
}
