#include "VolSorter.h"

/*!
* @class VolSorter
* @brief sorts layers according to their volatility 
*	
*/

/*!
* @brief default constructor
*	
*/
VolSorter::VolSorter(void)
{
}

/*!
* @brief returns sorting name
* @return QString: sorting name 
*	
*/
QString VolSorter::getName()
{
	return "Volatility Sorting, Evenly Weighted";
}

/*!
* @brief operator for sort()
* @param Layer aL: layer a for comparing
* @param Layer bL: layer b for comparing
* @return bool: true if a<b
*	
*/
bool volFunc (Layer aL,Layer bL) { return (aL.volatility<bL.volatility); }

/*!
* @brief sorts layers according to volatility
* @param Layer* layers: layers to be sorted
* @param int numLayers: number of layers
* @return Layer*: sorted layers
*	
*/
Layer* VolSorter::sortLayers(Layer* layers, int numLayers) {
	vector <Layer> temp;


	for(int i=0; i<numLayers; i++){
		temp.push_back(layers[i]);
	}

	sort (temp.begin(), temp.end(), volFunc);  

	for(int i=0; i<numLayers; i++){
		layers[i] = temp.at(i);
	}
	
	return orderToOutside(layers, numLayers);
}

/*!
* @brief default destructor
*	
*/
VolSorter::~VolSorter(void)
{
}
